# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/bixo/calendars/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/bixo/calendars/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Bixo\\Calendars\\": "packages/bixo/calendars/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Bixo\Calendars\Providers\CalendarsServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Calendars'  => Bixo\Calendars\Facades\Calendars::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Bixo\\CalendarsTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Bixo\Calendars\Providers\CalendarsServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Bixo\Calendars\Providers\CalendarsServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Bixo\Calendars\Providers\CalendarsServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/calendars/{modulename}

**User**

    http://path-to-route-folder/user/calendars/{modulename}

**Public**

    http://path-to-route-folder/calendars


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/calendars/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/calendars/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/calendars/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/calendars/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/calendars/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/calendars/{modulename}/{slug}
    METHOD: GET