<?php

namespace Bixo\Calendars\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Calendars\Http\Requests\CalendarRequest;
use Bixo\Calendars\Interfaces\CalendarRepositoryInterface;
use Bixo\Calendars\Models\Calendar;
use Bixo\Calendars\Forms\Calendar as Form;

/**
 * APIController  class for calendar.
 */
class CalendarAPIController extends BaseController
{

    /**
     * Initialize calendar resource controller.
     *
     * @param type CalendarRepositoryInterface $calendar
     *
     * @return null
     */
    public function __construct(CalendarRepositoryInterface $calendar)
    {
        parent::__construct();
        $this->repository = $calendar;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Calendars\Repositories\Criteria\CalendarResourceCriteria::class);
    }

    /**
     * Display a list of calendar.
     *
     * @return Response
     */
    public function index(CalendarRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Calendars\Repositories\Presenter\CalendarPresenter::class)
            ->paginate();
    }

    /**
     * Display calendar.
     *
     * @param Request $request
     * @param Model   $calendar
     *
     * @return Response
     */
    public function show(CalendarRequest $request, Calendar $calendar)
    {
        return $calendar->setPresenter(\Bixo\Calendars\Repositories\Presenter\CalendarListPresenter::class);
        ;
    }

    /**
     * Create new calendar.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CalendarRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('calendars::calendar.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('calendars/calendar/' . $calendar->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('calendars/calendar');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the calendar.
     *
     * @param Request $request
     * @param Model   $calendar
     *
     * @return Response
     */
    public function update(CalendarRequest $request, Calendar $calendar)
    {
        try {
            $data = $request->all();

            $calendar->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('calendars::calendar.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('calendars/calendar/' . $calendar->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('calendars/calendar/' . $calendar->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the calendar.
     *
     * @param Model   $calendar
     *
     * @return Response
     */
    public function destroy(CalendarRequest $request, Calendar $calendar)
    {
        try {
            $calendar->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('calendars::calendar.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('calendars/calendar/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('calendars/calendar/' . $calendar->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
